@@ -4,8 +4,7 @@ import discretize
 from ipywidgets import Dropdown, Text, FloatText, RadioButtons
 import matplotlib.pyplot as plt
 import numpy as np
-import ezdxf
-from geoh5py.objects import BlockModel, Curve, Octree, Points, Surface
+from geoh5py.objects import BlockModel, Curve, Octree
 from geoh5py.workspace import Workspace
 from ipywidgets.widgets import HBox, VBox
 from geoapps.plotting import plot_plan_data_selection
@@ -38,7 +37,7 @@ class Export(ObjectDataSelection):
     def __init__(self, **kwargs):
         kwargs = self.apply_defaults(**kwargs)
         self._file_type = Dropdown(
-            options=["ESRI shapefile", "csv", "geotiff", "UBC format", "dxf"],
+            options=["ESRI shapefile", "csv", "geotiff", "UBC format"],
             value="csv",
             description="Export type",
         )
@@ -61,8 +60,10 @@ class Export(ObjectDataSelection):
         super().__init__(**kwargs)
         self.trigger.description = "Export"
 
+        def save_selection(_):
+            self.save_selection()
 
-        self.trigger.on_click(self.save_selection)
+        self.trigger.on_click(save_selection)
 
         self._widget = VBox(
             [
@@ -163,7 +164,7 @@ class Export(ObjectDataSelection):
         self.export_directory._set_form_values(export_path, "")
         self.export_directory._apply_selection()
 
-    def save_selection(self, _):
+    def save_selection(self):
         if self.workspace.get_entity(self.objects.value):
             entity = self.workspace.get_entity(self.objects.value)[0]
         else:
@@ -287,34 +288,6 @@ class Export(ObjectDataSelection):
                     models=models,
                 )
 
-            elif self.file_type.value == "dxf":
-                print(entity, "In DXF")
-                drawing = ezdxf.new(dxfversion='AC1024')
-                modelspace = drawing.modelspace()
-
-                if isinstance(entity, Curve):
-                    cell_parts = entity.parts[entity.cells[:, 0]]
-
-                    for part in np.unique(entity.parts).tolist():
-                        ind = cell_parts == part
-                        poly = modelspace.add_polyline3d(
-                            entity.vertices[entity.cells[ind, 0], :].tolist()
-                        )
-
-                elif isinstance(entity, Points):
-                    modelspace.add_point(entity.vertices.tolist())
-                elif isinstance(entity, Surface):
-                    surf = modelspace.add_mesh()
-                    surf.vertices = entity.vertices.to_list()
-                    surf.edges = entity.cells.tolist()
-                else:
-                    print("DXF export only supports Points, Curve and Surface objects")
-                    # poly.dxf.true_color = 0xFF0000
-
-                drawing.saveas(
-                    path.join(self.export_directory.selected_path, self.export_as.value)
-                    + ".dxf"
-                )
             else:
 
                 mesh = discretize.TensorMesh(
