@@ -2,6 +2,7 @@ import numpy as np
 import scipy.sparse as sp
 from scipy.constants import mu_0
 
+# from dask.distributed import Client, LocalCluster
 from .. import Utils
 from .. import Problem
 from .. import Props
@@ -1099,7 +1100,7 @@ def calcRow(
     OUTPUT:
 
     """
-    eps = 1e-8  # add a small value to the locations to avoid /0
+    eps = 1e-16  # add a small value to the locations to avoid /0
     # number of cells in mesh
     nC = Xn.shape[0]
 
@@ -1140,61 +1141,61 @@ def calcRow(
     r8 = np.sqrt(dz1dz1 + R3) + eps
 
     # compactify argument calculations
-    arg1_ = dx1 + dy2 + r1
-    arg1 = dy2 + dz2 + r1
-    arg2 = dx1 + dz2 + r1
-    arg3 = dx1 + r1
-    arg4 = dy2 + r1
-    arg5 = dz2 + r1
+    arg1_ = dx1 + dy2 + r1 + eps
+    arg1 = dy2 + dz2 + r1 + eps
+    arg2 = dx1 + dz2 + r1 + eps
+    arg3 = dx1 + r1 + eps
+    arg4 = dy2 + r1 + eps
+    arg5 = dz2 + r1 + eps
 
-    arg6_ = dx2 + dy2 + r2
-    arg6 = dy2 + dz2 + r2
-    arg7 = dx2 + dz2 + r2
-    arg8 = dx2 + r2
-    arg9 = dy2 + r2
-    arg10 = dz2 + r2
+    arg6_ = dx2 + dy2 + r2 + eps
+    arg6 = dy2 + dz2 + r2 + eps
+    arg7 = dx2 + dz2 + r2 + eps
+    arg8 = dx2 + r2 + eps
+    arg9 = dy2 + r2 + eps
+    arg10 = dz2 + r2 + eps
 
-    arg11_ = dx2 + dy2 + r3
-    arg11 = dy2 + dz1 + r3
-    arg12 = dx2 + dz1 + r3
-    arg13 = dx2 + r3
-    arg14 = dy2 + r3
-    arg15 = dz1 + r3
+    arg11_ = dx2 + dy2 + r3 + eps
+    arg11 = dy2 + dz1 + r3 + eps
+    arg12 = dx2 + dz1 + r3 + eps
+    arg13 = dx2 + r3 + eps
+    arg14 = dy2 + r3 + eps
+    arg15 = dz1 + r3 + eps
 
-    arg16_ = dx1 + dy2 + r4
-    arg16 = dy2 + dz1 + r4
-    arg17 = dx1 + dz1 + r4
-    arg18 = dx1 + r4
-    arg19 = dy2 + r4
-    arg20 = dz1 + r4
+    arg16_ = dx1 + dy2 + r4 + eps
+    arg16 = dy2 + dz1 + r4 + eps
+    arg17 = dx1 + dz1 + r4 + eps
+    arg18 = dx1 + r4 + eps
+    arg19 = dy2 + r4 + eps
+    arg20 = dz1 + r4 + eps
 
-    arg21_ = dx2 + dy1 + r5
-    arg21 = dy1 + dz2 + r5
-    arg22 = dx2 + dz2 + r5
-    arg23 = dx2 + r5
-    arg24 = dy1 + r5
-    arg25 = dz2 + r5
+    arg21_ = dx2 + dy1 + r5 + eps
+    arg21 = dy1 + dz2 + r5 + eps
+    arg22 = dx2 + dz2 + r5 + eps
+    arg23 = dx2 + r5 + eps
+    arg24 = dy1 + r5 + eps
+    arg25 = dz2 + r5 + eps
 
-    arg26_ = dx1 + dy1 + r6
-    arg26 = dy1 + dz2 + r6
-    arg27 = dx1 + dz2 + r6
-    arg28 = dx1 + r6
-    arg29 = dy1 + r6
-    arg30 = dz2 + r6
+    arg26_ = dx1 + dy1 + r6 + eps
+    arg26 = dy1 + dz2 + r6 + eps
+    arg27 = dx1 + dz2 + r6 + eps
+    arg28 = dx1 + r6 + eps
+    arg29 = dy1 + r6 + eps
+    arg30 = dz2 + r6 + eps
 
-    arg31_ = dx1 + dy1 + r7
-    arg31 = dy1 + dz1 + r7
-    arg32 = dx1 + dz1 + r7
-    arg33 = dx1 + r7
-    arg34 = dy1 + r7
-    arg35 = dz1 + r7
+    arg31_ = dx1 + dy1 + r7 + eps
+    arg31 = dy1 + dz1 + r7 + eps
+    arg32 = dx1 + dz1 + r7 + eps
+    arg33 = dx1 + r7 + eps
+    arg34 = dy1 + r7 + eps
+    arg35 = dz1 + r7 + eps
 
-    arg36_ = dx2 + dy1 + r8
-    arg36 = dy1 + dz1 + r8
-    arg37 = dx2 + dz1 + r8
-    arg38 = dx2 + r8
-    arg39 = dy1 + r8
-    arg40 = dz1 + r8
+    arg36_ = dx2 + dy1 + r8 + eps
+    arg36 = dy1 + dz1 + r8 + eps
+    arg37 = dx2 + dz1 + r8 + eps
+    arg38 = dx2 + r8 + eps
+    arg39 = dy1 + r8 + eps
+    arg40 = dz1 + r8 + eps
 
     rows = []
     bxx, byy = [], []
@@ -1204,36 +1205,36 @@ def calcRow(
             bxx = np.zeros((1, 3 * nC))
 
             bxx[0, 0:nC] = 2 * (
-                ((dx1 ** 2 - r1 * arg1) / (r1 * arg1 ** 2 + dx1 ** 2 * r1 + eps))
-                - ((dx2 ** 2 - r2 * arg6) / (r2 * arg6 ** 2 + dx2 ** 2 * r2 + eps))
-                + ((dx2 ** 2 - r3 * arg11) / (r3 * arg11 ** 2 + dx2 ** 2 * r3 + eps))
-                - ((dx1 ** 2 - r4 * arg16) / (r4 * arg16 ** 2 + dx1 ** 2 * r4 + eps))
-                + ((dx2 ** 2 - r5 * arg21) / (r5 * arg21 ** 2 + dx2 ** 2 * r5 + eps))
-                - ((dx1 ** 2 - r6 * arg26) / (r6 * arg26 ** 2 + dx1 ** 2 * r6 + eps))
-                + ((dx1 ** 2 - r7 * arg31) / (r7 * arg31 ** 2 + dx1 ** 2 * r7 + eps))
-                - ((dx2 ** 2 - r8 * arg36) / (r8 * arg36 ** 2 + dx2 ** 2 * r8 + eps))
+                ((dx1 ** 2 - r1 * arg1) / (r1 * arg1 ** 2 + dx1 ** 2 * r1))
+                - ((dx2 ** 2 - r2 * arg6) / (r2 * arg6 ** 2 + dx2 ** 2 * r2))
+                + ((dx2 ** 2 - r3 * arg11) / (r3 * arg11 ** 2 + dx2 ** 2 * r3))
+                - ((dx1 ** 2 - r4 * arg16) / (r4 * arg16 ** 2 + dx1 ** 2 * r4))
+                + ((dx2 ** 2 - r5 * arg21) / (r5 * arg21 ** 2 + dx2 ** 2 * r5))
+                - ((dx1 ** 2 - r6 * arg26) / (r6 * arg26 ** 2 + dx1 ** 2 * r6))
+                + ((dx1 ** 2 - r7 * arg31) / (r7 * arg31 ** 2 + dx1 ** 2 * r7))
+                - ((dx2 ** 2 - r8 * arg36) / (r8 * arg36 ** 2 + dx2 ** 2 * r8))
             )
 
             bxx[0, nC : 2 * nC] = (
-                dx2 / (r5 * arg25 + eps)
-                - dx2 / (r2 * arg10 + eps)
-                + dx2 / (r3 * arg15 + eps)
-                - dx2 / (r8 * arg40 + eps)
-                + dx1 / (r1 * arg5 + eps)
-                - dx1 / (r6 * arg30 + eps)
-                + dx1 / (r7 * arg35 + eps)
-                - dx1 / (r4 * arg20 + eps)
+                dx2 / (r5 * arg25)
+                - dx2 / (r2 * arg10)
+                + dx2 / (r3 * arg15)
+                - dx2 / (r8 * arg40)
+                + dx1 / (r1 * arg5)
+                - dx1 / (r6 * arg30)
+                + dx1 / (r7 * arg35)
+                - dx1 / (r4 * arg20)
             )
 
             bxx[0, 2 * nC :] = (
-                dx1 / (r1 * arg4 + eps)
-                - dx2 / (r2 * arg9 + eps)
-                + dx2 / (r3 * arg14 + eps)
-                - dx1 / (r4 * arg19 + eps)
-                + dx2 / (r5 * arg24 + eps)
-                - dx1 / (r6 * arg29 + eps)
-                + dx1 / (r7 * arg34 + eps)
-                - dx2 / (r8 * arg39 + eps)
+                dx1 / (r1 * arg4)
+                - dx2 / (r2 * arg9)
+                + dx2 / (r3 * arg14)
+                - dx1 / (r4 * arg19)
+                + dx2 / (r5 * arg24)
+                - dx1 / (r6 * arg29)
+                + dx1 / (r7 * arg34)
+                - dx2 / (r8 * arg39)
             )
 
             bxx /= 4 * np.pi
@@ -1243,34 +1244,34 @@ def calcRow(
             byy = np.zeros((1, 3 * nC))
 
             byy[0, 0:nC] = (
-                dy2 / (r3 * arg15 + eps)
-                - dy2 / (r2 * arg10 + eps)
-                + dy1 / (r5 * arg25 + eps)
-                - dy1 / (r8 * arg40 + eps)
-                + dy2 / (r1 * arg5 + eps)
-                - dy2 / (r4 * arg20 + eps)
-                + dy1 / (r7 * arg35 + eps)
-                - dy1 / (r6 * arg30 + eps)
+                dy2 / (r3 * arg15)
+                - dy2 / (r2 * arg10)
+                + dy1 / (r5 * arg25)
+                - dy1 / (r8 * arg40)
+                + dy2 / (r1 * arg5)
+                - dy2 / (r4 * arg20)
+                + dy1 / (r7 * arg35)
+                - dy1 / (r6 * arg30)
             )
             byy[0, nC : 2 * nC] = 2 * (
-                ((dy2 ** 2 - r1 * arg2) / (r1 * arg2 ** 2 + dy2 ** 2 * r1 + eps))
-                - ((dy2 ** 2 - r2 * arg7) / (r2 * arg7 ** 2 + dy2 ** 2 * r2 + eps))
-                + ((dy2 ** 2 - r3 * arg12) / (r3 * arg12 ** 2 + dy2 ** 2 * r3 + eps))
-                - ((dy2 ** 2 - r4 * arg17) / (r4 * arg17 ** 2 + dy2 ** 2 * r4 + eps))
-                + ((dy1 ** 2 - r5 * arg22) / (r5 * arg22 ** 2 + dy1 ** 2 * r5 + eps))
-                - ((dy1 ** 2 - r6 * arg27) / (r6 * arg27 ** 2 + dy1 ** 2 * r6 + eps))
-                + ((dy1 ** 2 - r7 * arg32) / (r7 * arg32 ** 2 + dy1 ** 2 * r7 + eps))
-                - ((dy1 ** 2 - r8 * arg37) / (r8 * arg37 ** 2 + dy1 ** 2 * r8 + eps))
+                ((dy2 ** 2 - r1 * arg2) / (r1 * arg2 ** 2 + dy2 ** 2 * r1))
+                - ((dy2 ** 2 - r2 * arg7) / (r2 * arg7 ** 2 + dy2 ** 2 * r2))
+                + ((dy2 ** 2 - r3 * arg12) / (r3 * arg12 ** 2 + dy2 ** 2 * r3))
+                - ((dy2 ** 2 - r4 * arg17) / (r4 * arg17 ** 2 + dy2 ** 2 * r4))
+                + ((dy1 ** 2 - r5 * arg22) / (r5 * arg22 ** 2 + dy1 ** 2 * r5))
+                - ((dy1 ** 2 - r6 * arg27) / (r6 * arg27 ** 2 + dy1 ** 2 * r6))
+                + ((dy1 ** 2 - r7 * arg32) / (r7 * arg32 ** 2 + dy1 ** 2 * r7))
+                - ((dy1 ** 2 - r8 * arg37) / (r8 * arg37 ** 2 + dy1 ** 2 * r8))
             )
             byy[0, 2 * nC :] = (
-                dy2 / (r1 * arg3 + eps)
-                - dy2 / (r2 * arg8 + eps)
-                + dy2 / (r3 * arg13 + eps)
-                - dy2 / (r4 * arg18 + eps)
-                + dy1 / (r5 * arg23 + eps)
-                - dy1 / (r6 * arg28 + eps)
-                + dy1 / (r7 * arg33 + eps)
-                - dy1 / (r8 * arg38 + eps)
+                dy2 / (r1 * arg3)
+                - dy2 / (r2 * arg8)
+                + dy2 / (r3 * arg13)
+                - dy2 / (r4 * arg18)
+                + dy1 / (r5 * arg23)
+                - dy1 / (r6 * arg28)
+                + dy1 / (r7 * arg33)
+                - dy1 / (r8 * arg38)
             )
 
             byy /= 4 * np.pi
@@ -1292,24 +1293,24 @@ def calcRow(
             bxy = np.zeros((1, 3 * nC))
 
             bxy[0, 0:nC] = 2 * (
-                ((dx1 * arg4) / (r1 * arg1 ** 2 + (dx1 ** 2) * r1 + eps))
-                - ((dx2 * arg9) / (r2 * arg6 ** 2 + (dx2 ** 2) * r2 + eps))
-                + ((dx2 * arg14) / (r3 * arg11 ** 2 + (dx2 ** 2) * r3 + eps))
-                - ((dx1 * arg19) / (r4 * arg16 ** 2 + (dx1 ** 2) * r4 + eps))
-                + ((dx2 * arg24) / (r5 * arg21 ** 2 + (dx2 ** 2) * r5 + eps))
-                - ((dx1 * arg29) / (r6 * arg26 ** 2 + (dx1 ** 2) * r6 + eps))
-                + ((dx1 * arg34) / (r7 * arg31 ** 2 + (dx1 ** 2) * r7 + eps))
-                - ((dx2 * arg39) / (r8 * arg36 ** 2 + (dx2 ** 2) * r8 + eps))
+                ((dx1 * arg4) / (r1 * arg1 ** 2 + (dx1 ** 2) * r1))
+                - ((dx2 * arg9) / (r2 * arg6 ** 2 + (dx2 ** 2) * r2))
+                + ((dx2 * arg14) / (r3 * arg11 ** 2 + (dx2 ** 2) * r3))
+                - ((dx1 * arg19) / (r4 * arg16 ** 2 + (dx1 ** 2) * r4))
+                + ((dx2 * arg24) / (r5 * arg21 ** 2 + (dx2 ** 2) * r5))
+                - ((dx1 * arg29) / (r6 * arg26 ** 2 + (dx1 ** 2) * r6))
+                + ((dx1 * arg34) / (r7 * arg31 ** 2 + (dx1 ** 2) * r7))
+                - ((dx2 * arg39) / (r8 * arg36 ** 2 + (dx2 ** 2) * r8))
             )
             bxy[0, nC : 2 * nC] = (
-                dy2 / (r1 * arg5 + eps)
-                - dy2 / (r2 * arg10 + eps)
-                + dy2 / (r3 * arg15 + eps)
-                - dy2 / (r4 * arg20 + eps)
-                + dy1 / (r5 * arg25 + eps)
-                - dy1 / (r6 * arg30 + eps)
-                + dy1 / (r7 * arg35 + eps)
-                - dy1 / (r8 * arg40 + eps)
+                dy2 / (r1 * arg5)
+                - dy2 / (r2 * arg10)
+                + dy2 / (r3 * arg15)
+                - dy2 / (r4 * arg20)
+                + dy1 / (r5 * arg25)
+                - dy1 / (r6 * arg30)
+                + dy1 / (r7 * arg35)
+                - dy1 / (r8 * arg40)
             )
             bxy[0, 2 * nC :] = (
                 1 / r1 - 1 / r2 + 1 / r3 - 1 / r4 + 1 / r5 - 1 / r6 + 1 / r7 - 1 / r8
@@ -1323,27 +1324,27 @@ def calcRow(
             bxz = np.zeros((1, 3 * nC))
 
             bxz[0, 0:nC] = 2 * (
-                ((dx1 * arg5) / (r1 * (arg1 ** 2) + (dx1 ** 2) * r1 + eps))
-                - ((dx2 * arg10) / (r2 * (arg6 ** 2) + (dx2 ** 2) * r2 + eps))
-                + ((dx2 * arg15) / (r3 * (arg11 ** 2) + (dx2 ** 2) * r3 + eps))
-                - ((dx1 * arg20) / (r4 * (arg16 ** 2) + (dx1 ** 2) * r4 + eps))
-                + ((dx2 * arg25) / (r5 * (arg21 ** 2) + (dx2 ** 2) * r5 + eps))
-                - ((dx1 * arg30) / (r6 * (arg26 ** 2) + (dx1 ** 2) * r6 + eps))
-                + ((dx1 * arg35) / (r7 * (arg31 ** 2) + (dx1 ** 2) * r7 + eps))
-                - ((dx2 * arg40) / (r8 * (arg36 ** 2) + (dx2 ** 2) * r8 + eps))
+                ((dx1 * arg5) / (r1 * (arg1 ** 2) + (dx1 ** 2) * r1))
+                - ((dx2 * arg10) / (r2 * (arg6 ** 2) + (dx2 ** 2) * r2))
+                + ((dx2 * arg15) / (r3 * (arg11 ** 2) + (dx2 ** 2) * r3))
+                - ((dx1 * arg20) / (r4 * (arg16 ** 2) + (dx1 ** 2) * r4))
+                + ((dx2 * arg25) / (r5 * (arg21 ** 2) + (dx2 ** 2) * r5))
+                - ((dx1 * arg30) / (r6 * (arg26 ** 2) + (dx1 ** 2) * r6))
+                + ((dx1 * arg35) / (r7 * (arg31 ** 2) + (dx1 ** 2) * r7))
+                - ((dx2 * arg40) / (r8 * (arg36 ** 2) + (dx2 ** 2) * r8))
             )
             bxz[0, nC : 2 * nC] = (
                 1 / r1 - 1 / r2 + 1 / r3 - 1 / r4 + 1 / r5 - 1 / r6 + 1 / r7 - 1 / r8
             )
             bxz[0, 2 * nC :] = (
-                dz2 / (r1 * arg4 + eps)
-                - dz2 / (r2 * arg9 + eps)
-                + dz1 / (r3 * arg14 + eps)
-                - dz1 / (r4 * arg19 + eps)
-                + dz2 / (r5 * arg24 + eps)
-                - dz2 / (r6 * arg29 + eps)
-                + dz1 / (r7 * arg34 + eps)
-                - dz1 / (r8 * arg39 + eps)
+                dz2 / (r1 * arg4)
+                - dz2 / (r2 * arg9)
+                + dz1 / (r3 * arg14)
+                - dz1 / (r4 * arg19)
+                + dz2 / (r5 * arg24)
+                - dz2 / (r6 * arg29)
+                + dz1 / (r7 * arg34)
+                - dz1 / (r8 * arg39)
             )
 
             bxz /= 4 * np.pi
@@ -1357,24 +1358,24 @@ def calcRow(
                 1 / r3 - 1 / r2 + 1 / r5 - 1 / r8 + 1 / r1 - 1 / r4 + 1 / r7 - 1 / r6
             )
             byz[0, nC : 2 * nC] = 2 * (
-                ((dy2 * arg5) / (r1 * (arg2 ** 2) + (dy2 ** 2) * r1 + eps))
-                - ((dy2 * arg10) / (r2 * (arg7 ** 2) + (dy2 ** 2) * r2 + eps))
-                + ((dy2 * arg15) / (r3 * (arg12 ** 2) + (dy2 ** 2) * r3 + eps))
-                - ((dy2 * arg20) / (r4 * (arg17 ** 2) + (dy2 ** 2) * r4 + eps))
-                + ((dy1 * arg25) / (r5 * (arg22 ** 2) + (dy1 ** 2) * r5 + eps))
-                - ((dy1 * arg30) / (r6 * (arg27 ** 2) + (dy1 ** 2) * r6 + eps))
-                + ((dy1 * arg35) / (r7 * (arg32 ** 2) + (dy1 ** 2) * r7 + eps))
-                - ((dy1 * arg40) / (r8 * (arg37 ** 2) + (dy1 ** 2) * r8 + eps))
+                ((dy2 * arg5) / (r1 * (arg2 ** 2) + (dy2 ** 2) * r1))
+                - ((dy2 * arg10) / (r2 * (arg7 ** 2) + (dy2 ** 2) * r2))
+                + ((dy2 * arg15) / (r3 * (arg12 ** 2) + (dy2 ** 2) * r3))
+                - ((dy2 * arg20) / (r4 * (arg17 ** 2) + (dy2 ** 2) * r4))
+                + ((dy1 * arg25) / (r5 * (arg22 ** 2) + (dy1 ** 2) * r5))
+                - ((dy1 * arg30) / (r6 * (arg27 ** 2) + (dy1 ** 2) * r6))
+                + ((dy1 * arg35) / (r7 * (arg32 ** 2) + (dy1 ** 2) * r7))
+                - ((dy1 * arg40) / (r8 * (arg37 ** 2) + (dy1 ** 2) * r8))
             )
             byz[0, 2 * nC :] = (
-                dz2 / (r1 * arg3 + eps)
-                - dz2 / (r2 * arg8 + eps)
-                + dz1 / (r3 * arg13 + eps)
-                - dz1 / (r4 * arg18 + eps)
-                + dz2 / (r5 * arg23 + eps)
-                - dz2 / (r6 * arg28 + eps)
-                + dz1 / (r7 * arg33 + eps)
-                - dz1 / (r8 * arg38 + eps)
+                dz2 / (r1 * arg3)
+                - dz2 / (r2 * arg8)
+                + dz1 / (r3 * arg13)
+                - dz1 / (r4 * arg18)
+                + dz2 / (r5 * arg23)
+                - dz2 / (r6 * arg28)
+                + dz1 / (r7 * arg33)
+                - dz1 / (r8 * arg38)
             )
 
             byz /= 4 * np.pi
@@ -1385,14 +1386,14 @@ def calcRow(
             bx = np.zeros((1, 3 * nC))
 
             bx[0, 0:nC] = (
-                (-2 * np.arctan2(dx1, arg1 + eps))
-                - (-2 * np.arctan2(dx2, arg6 + eps))
-                + (-2 * np.arctan2(dx2, arg11 + eps))
-                - (-2 * np.arctan2(dx1, arg16 + eps))
-                + (-2 * np.arctan2(dx2, arg21 + eps))
-                - (-2 * np.arctan2(dx1, arg26 + eps))
-                + (-2 * np.arctan2(dx1, arg31 + eps))
-                - (-2 * np.arctan2(dx2, arg36 + eps))
+                (-2 * np.arctan2(dx1, arg1))
+                - (-2 * np.arctan2(dx2, arg6))
+                + (-2 * np.arctan2(dx2, arg11))
+                - (-2 * np.arctan2(dx1, arg16))
+                + (-2 * np.arctan2(dx2, arg21))
+                - (-2 * np.arctan2(dx1, arg26))
+                + (-2 * np.arctan2(dx1, arg31))
+                - (-2 * np.arctan2(dx2, arg36))
             )
             bx[0, nC : 2 * nC] = (
                 np.log(arg5)
@@ -1428,14 +1429,14 @@ def calcRow(
                 - np.log(arg40)
             )
             by[0, nC : 2 * nC] = (
-                (-2 * np.arctan2(dy2, arg2 + eps))
-                - (-2 * np.arctan2(dy2, arg7 + eps))
-                + (-2 * np.arctan2(dy2, arg12 + eps))
-                - (-2 * np.arctan2(dy2, arg17 + eps))
-                + (-2 * np.arctan2(dy1, arg22 + eps))
-                - (-2 * np.arctan2(dy1, arg27 + eps))
-                + (-2 * np.arctan2(dy1, arg32 + eps))
-                - (-2 * np.arctan2(dy1, arg37 + eps))
+                (-2 * np.arctan2(dy2, arg2))
+                - (-2 * np.arctan2(dy2, arg7))
+                + (-2 * np.arctan2(dy2, arg12))
+                - (-2 * np.arctan2(dy2, arg17))
+                + (-2 * np.arctan2(dy1, arg22))
+                - (-2 * np.arctan2(dy1, arg27))
+                + (-2 * np.arctan2(dy1, arg32))
+                - (-2 * np.arctan2(dy1, arg37))
             )
             by[0, 2 * nC :] = (
                 (np.log(arg3) - np.log(arg8))
@@ -1468,14 +1469,14 @@ def calcRow(
                 + (np.log(arg33) - np.log(arg38))
             )
             bz[0, 2 * nC :] = (
-                (-2 * np.arctan2(dz2, arg1_ + eps))
-                - (-2 * np.arctan2(dz2, arg6_ + eps))
-                + (-2 * np.arctan2(dz1, arg11_ + eps))
-                - (-2 * np.arctan2(dz1, arg16_ + eps))
-                + (-2 * np.arctan2(dz2, arg21_ + eps))
-                - (-2 * np.arctan2(dz2, arg26_ + eps))
-                + (-2 * np.arctan2(dz1, arg31_ + eps))
-                - (-2 * np.arctan2(dz1, arg36_ + eps))
+                (-2 * np.arctan2(dz2, arg1_))
+                - (-2 * np.arctan2(dz2, arg6_))
+                + (-2 * np.arctan2(dz1, arg11_))
+                - (-2 * np.arctan2(dz1, arg16_))
+                + (-2 * np.arctan2(dz2, arg21_))
+                - (-2 * np.arctan2(dz2, arg26_))
+                + (-2 * np.arctan2(dz1, arg31_))
+                - (-2 * np.arctan2(dz1, arg36_))
             )
             bz /= -4 * np.pi
 
