@@ -21,4 +21,6 @@ from .utils import (
     symlog,
     tensor_2_block_model,
     treemesh_2_octree,
+    random_sampling,
+    hex_to_rgb,
 )
